Index: libcfa/configure
===================================================================
--- libcfa/configure	(revision 8f74a6a90dfafe7f15a3b81e2fb32de2141df58c)
+++ libcfa/configure	(revision c9e640efad4c1995846cf711a7ae8d838abeaaeb)
@@ -2970,5 +2970,5 @@
 	"nolib"   )
 		CONFIG_CFLAGS="-O2 -s"
-		CONFIG_CFAFLAGS="-nodebug"
+		CONFIG_CFAFLAGS="-nolib"
 		CONFIG_BUILDLIB="no"
 	;;
Index: libcfa/configure.ac
===================================================================
--- libcfa/configure.ac	(revision 8f74a6a90dfafe7f15a3b81e2fb32de2141df58c)
+++ libcfa/configure.ac	(revision c9e640efad4c1995846cf711a7ae8d838abeaaeb)
@@ -56,5 +56,5 @@
 	"nolib"   )
 		CONFIG_CFLAGS="-O2 -s"
-		CONFIG_CFAFLAGS="-nodebug"
+		CONFIG_CFAFLAGS="-nolib"
 		CONFIG_BUILDLIB="no"
 	;;

Index: driver/cfa.cc
===================================================================
--- driver/cfa.cc	(revision 8f74a6a90dfafe7f15a3b81e2fb32de2141df58c)
+++ driver/cfa.cc	(revision c9e640efad4c1995846cf711a7ae8d838abeaaeb)
@@ -107,7 +107,8 @@
 	bool link = true;									// linking as well as compiling
 	bool verbose = false;								// -v flag
-	bool quiet = false;									// -quiet flag
-	bool debug = true;									// -debug flag
-	bool help = false;									// -help flag
+	bool quiet = false;								// -quiet flag
+	bool debug = true;								// -debug flag
+	bool nolib = false;								// -nolib flag
+	bool help = false;								// -help flag
 	bool CFA_flag = false;								// -CFA flag
 	bool cpp_flag = false;								// -E or -M flag, preprocessor only
@@ -162,5 +163,7 @@
 				debug = true;							// strip the debug flag
 			} else if ( arg == "-nodebug" ) {
-				debug = false;							// strip the nodebug flag
+				debug = false;							// strip the debug flag
+			} else if ( arg == "-nolib" ) {
+				nolib = true;							// strip the nodebug flag
 			} else if ( arg == "-quiet" ) {
 				quiet = true;							// strip the quiet flag
@@ -366,8 +369,8 @@
 		}  // if
 	} // if
-	const char * config = debug ? "debug": "nodebug";
+	const char * config = nolib ? "nolib" : (debug ? "debug": "nodebug");
 	string libdir = libbase + arch + "-" + config;
 
-	if ( ! dirExists( libdir ) ) {
+	if ( ! nolib && ! dirExists( libdir ) ) {
 		cerr << argv[0] << " internal error, configuration " << config << " not installed." << endl;
 		cerr << "Was looking for " << libdir << endl;